/****
	Speedometer, shows your current speed using GPS
	Copyright (C) 2008 Wellu Mäkinen <wellu@wellu.org>

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/

#include <hildon/hildon-program.h>
#include <hildon/hildon-window.h>
#include <stdlib.h>
#include <gtk/gtk.h>
#include <location/location-gps-device.h>
#include <location/location-gpsd-control.h>

#include "callbacks.h"
#include "appdata.h"
#include "ui.h"

int main(int argc, char** argv) {

	AppData *appdata = g_new0(AppData, 1);

	gtk_init(&argc, &argv);


	GtkWidget *hbox;
	GtkWidget *vbox;

	appdata->program = HILDON_PROGRAM(hildon_program_get_instance());
	appdata->window = HILDON_WINDOW(hildon_window_new());
	hildon_program_add_window(appdata->program, appdata->window);

	set_app_bg_black(appdata);

	populate_image_array(appdata);

	load_default_images(appdata);

	vbox = gtk_vbox_new(FALSE, 0);
	hbox = gtk_hbox_new(TRUE, 0);

	gtk_box_pack_start_defaults(vbox, gtk_event_box_new());
	gtk_box_pack_start_defaults(vbox, hbox);

	gtk_box_pack_start(hbox, appdata->speed_array[0], FALSE, FALSE, 0);
	gtk_box_pack_start(hbox, appdata->speed_array[1], FALSE, FALSE, 0);
	gtk_box_pack_start(hbox, appdata->speed_array[2], FALSE, FALSE, 0);

	gtk_box_pack_start_defaults(vbox, gtk_button_new_with_label("Bottom"));

	gtk_container_add(GTK_CONTAINER(appdata->window), GTK_WIDGET(vbox));

	// set the window fullscreen
	gtk_window_fullscreen(GTK_WINDOW(appdata->window));

	gtk_widget_show_all(GTK_WIDGET(appdata->window));



	g_thread_init(NULL);

	g_idle_add(randomize, appdata);


#ifdef __arm__
	// gps device
	LocationGPSDevice *device;
	device = g_object_new(LOCATION_TYPE_GPS_DEVICE, NULL);

	// connect some signal handlers
	g_signal_connect (device, "changed", G_CALLBACK (location_changed), NULL);

	LocationGPSDControl *control;

	control = location_gpsd_control_get_default();
	location_gpsd_control_start(control);
#endif // __arm__

	g_signal_connect(G_OBJECT(appdata->window),
			"delete_event",
			G_CALLBACK(gtk_main_quit),
			NULL);

    g_signal_connect(G_OBJECT(appdata->window),
    		"key_press_event",
    		G_CALLBACK(key_press_cb),
    		appdata->window);

    g_signal_connect(G_OBJECT(appdata->window),
    		"button_press_event",
    		G_CALLBACK(button_press),
    		appdata->window);

    gtk_main();

	return EXIT_SUCCESS;
}

